.. _support:

Getting Help
============

There are multiple ways of getting help.

Chat
----

There is a `dedicated public Matrix chat`_.

.. _dedicated public Matrix chat: https://matrix.to/#/#abgleich:matrix.org

Reporting Bugs / Issues
-----------------------

Bugs and any kind of issues should be reported in the project's `Github issue tracker`_, also see :ref:`chapter on bugs <bugs>`.

.. _Github issue tracker: https://github.com/pleiszenburg/abgleich/issues

Paid Support
------------

In addition to the previous options, paid support is available from `pleiszenburg.de - Independent Scientific Services`_.

.. _pleiszenburg.de - Independent Scientific Services: https://www.pleiszenburg.de
